"""A switch product type."""

from orchestrator.domain.base import SubscriptionModel
from orchestrator.types import SubscriptionLifecycle

from gso.products.product_blocks.switch import SwitchBlock, SwitchBlockInactive, SwitchBlockProvisioning


class SwitchInactive(SubscriptionModel, is_base=True):
    """An inactive switch."""

    switch: SwitchBlockInactive


class SwitchProvisioning(SwitchInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING]):
    """A switch that is being provisioned."""

    switch: SwitchBlockProvisioning


class Switch(SwitchProvisioning, lifecycle=[SubscriptionLifecycle.ACTIVE]):
    """A switch that is currently active."""

    switch: SwitchBlock


class ImportedSwitchInactive(SubscriptionModel, is_base=True):
    """An imported, inactive switch."""

    switch: SwitchBlockInactive


class ImportedSwitch(
    ImportedSwitchInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING, SubscriptionLifecycle.ACTIVE]
):
    """An imported switch that is currently active."""

    switch: SwitchBlock
